## 0.3.1 (2021-06-08)

### Fix

- adapt to mkdocs 1.2

## 0.3.0 (2021-04-23)

## 0.2.1 (2021-03-29)

### Fix

- don't wrap commit messages when building articles

## 0.2.0 (2021-03-28)

### Feat

- add rss support

### feat

- create newsletter landing page

## 0.1.0 (2021-03-19)

### Fix

- add dateutil to required dependencies
- Remove links from the Other section

### Feat

- create newsletters from changes
- create initial project structure
